Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type EncodeType ¶
EncodeType is a struct that houses the value of our key which will be determined by the user at runtime.
type Encoder ¶
Encoder is an interface that allows us to implement our Encode function in order to fully encode our cookie values.
type Encrypt ¶
Encrypt holds the values for our 'HashKey' and 'BlockKey' as a struct. These values must be within the Advanced Encryption Standard.
func (*Encrypt) Keys ¶
func (e *Encrypt) Keys(v vObject) (*securecookie.SecureCookie, error)
Keys allows us to store our encryption keys securely for re-use.
Click to show internal directories.
Click to hide internal directories.